@@ -15,4 +15,6 @@ class APIError(SDKError):
         self.detail: Any = detail
 
     def __str__(self) -> str:
+        if self.status == 401:
+            return "请检查您的凭证信息，可能已经过期。"
         return f"[HTTP {self.status}] {self.message}" if self.status else self.message
