@@ -8,6 +8,7 @@ from pydantic import BaseModel, Field
 
 class DatasetVersionStatus(IntEnum):
     """数据集版本状态：1-等待中；2-运行中；3-成功；4-失败；5-加载meta；6-构建index"""
+
     Waiting = 1  # 等待中
     Running = 2  # 运行中
     Success = 3  # 成功
@@ -18,6 +19,7 @@ class DatasetVersionStatus(IntEnum):
 
 class UploadType(IntEnum):
     """上传类型：1-本地上传；3-服务器路径上传；4-Labelfree；5-数据接入"""
+
     LOCAL = 1  # 本地上传
     SERVER_PATH = 3  # 服务器路径上传
     LABELFREE = 4  # Labelfree
@@ -26,6 +28,7 @@ class UploadType(IntEnum):
 
 class CreateDatasetRequest(BaseModel):
     """创建数据集请求"""
+
     name: str = Field(description="数据集名称")
     description: str = Field(description="数据集描述")
     tags: List[int] = Field(description="标签ID列表，通过标签管理系统查询")
@@ -37,22 +40,26 @@ class CreateDatasetRequest(BaseModel):
 
 class CreateDatasetResponse(BaseModel):
     """创建数据集返回"""
+
     id: int = Field(alias="id", description="数据集ID")
 
 
 class DatasetVersionBase(BaseModel):
     """数据集版本概要"""
+
     id: int = Field(description="版本ID")
     version: int = Field(description="版本号")
     status: DatasetVersionStatus = Field(description="版本状态")
     parquet_index_path: Optional[str] = Field(None, alias="parquet_index_path", description="parquet索引文件路径")
     data_count: int = Field(alias="data_count", description="数量")
+    file_storage_path: Optional[str] = Field(None, alias="file_storage_path", description="文件存储路径")
 
     model_config = {"use_enum_values": True}
 
 
 class DatasetDetail(BaseModel):
     """数据集详情"""
+
     id: int = Field(description="数据集 ID")
     name: str = Field(description="名称")
     description: str = Field(description="描述")
@@ -69,6 +76,7 @@ class DatasetDetail(BaseModel):
 
 class ExtInfo(BaseModel):
     """扩展信息"""
+
     rec_file_path: Optional[str] = Field(None, alias="rec_file_path", description="rec文件路径")
     idx_file_path: Optional[str] = Field(None, alias="idx_file_path", description="idx文件路径")
     json_file_path: Optional[str] = Field(None, alias="json_file_path", description="json文件路径")
@@ -77,6 +85,7 @@ class ExtInfo(BaseModel):
 
 class CreateDatasetVersionRequest(BaseModel):
     """创建版本请求"""
+
     upload_path: str = Field(alias="upload_path", description="上传路径")
     description: Optional[str] = Field(None, description="版本描述")
     dataset_id: int = Field(alias="dataset_id", description="数据集ID")
@@ -91,11 +100,13 @@ class CreateDatasetVersionRequest(BaseModel):
 
 class CreateDatasetVersionResponse(BaseModel):
     """创建版本返回"""
+
     id: int = Field(alias="id", description="版本ID")
 
 
 class UploadDatasetVersionRequest(BaseModel):
     """上传数据集版本请求"""
+
     upload_path: str = Field(alias="upload_path", description="上传目录")
     upload_type: UploadType = Field(alias="upload_type", description="上传类型")
     dataset_id: int = Field(alias="dataset_id", description="数据集ID")
@@ -107,11 +118,13 @@ class UploadDatasetVersionRequest(BaseModel):
 
 class UploadDatasetVersionResponse(BaseModel):
     """上传数据集版本返回"""
+
     id: int = Field(alias="id", description="版本ID")
 
 
 class DatasetVersionDetail(BaseModel):
     """数据集版本详情"""
+
     id: int = Field(description="版本ID")
     version: int = Field(description="版本号")
     dataset_id: int = Field(alias="dataset_id", description="数据集ID")
@@ -133,12 +146,14 @@ class DatasetVersionDetail(BaseModel):
 
 class FileUploadData(BaseModel):
     """文件上传数据"""
+
     path: str = Field(description="路径")
     url: str = Field(description="URL")
 
 
 class ListDatasetReq(BaseModel):
     """列表查询数据集请求(使用 dataset_management v2)"""
+
     page_size: int = Field(20, alias="page_size", description="每页大小，默认20")
     page_num: int = Field(1, alias="page_num", description="页码，从1开始")
     name: Optional[str] = Field(None, description="数据集名称筛选")
@@ -149,6 +164,7 @@ class ListDatasetReq(BaseModel):
 
 class ListDatasetItem(BaseModel):
     """列表数据集项"""
+
     id: int = Field(description="数据集ID")
     name: str = Field(description="数据集名称")
     description: str = Field(description="数据集描述")
@@ -164,6 +180,7 @@ class ListDatasetItem(BaseModel):
 
 class ListDatasetResp(BaseModel):
     """列表查询数据集响应"""
+
     total: int = Field(description="总数")
     page_size: int = Field(alias="page_size", description="每页大小")
     page_num: int = Field(alias="page_num", description="当前页码")
@@ -172,14 +189,18 @@ class ListDatasetResp(BaseModel):
 
 class ListDatasetVersionReq(BaseModel):
     """列表查询数据集版本请求(使用 dataset_management v2)"""
+
     page_size: int = Field(10000000, alias="page_size", description="每页大小，默认10000000")
     page_num: int = Field(1, alias="page_num", description="页码，从1开始")
     dataset_id: Optional[int] = Field(None, alias="dataset_id", description="数据集ID筛选")
-    dataset_version_ids: Optional[str] = Field(None, alias="dataset_version_ids", description="数据集版本ID列表，逗号分隔")
+    dataset_version_ids: Optional[str] = Field(
+        None, alias="dataset_version_ids", description="数据集版本ID列表，逗号分隔"
+    )
 
 
 class ListDatasetVersionItem(BaseModel):
     """列表数据集版本项"""
+
     id: int = Field(description="版本ID")
     version: int = Field(description="版本号")
     dataset_id: int = Field(alias="dataset_id", description="数据集ID")
@@ -199,7 +220,20 @@ class ListDatasetVersionItem(BaseModel):
 
 class ListDatasetVersionResp(BaseModel):
     """列表查询数据集版本响应"""
+
     total: int = Field(description="总数")
     page_size: int = Field(alias="page_size", description="每页大小")
     page_num: int = Field(alias="page_num", description="当前页码")
     data: List[ListDatasetVersionItem] = Field(description="数据集版本列表")
+
+
+class CreateDatasetVersionByDataIngestReqV2(BaseModel):
+    """通过数据集成创建数据集版本请求"""
+
+    description: Optional[str] = Field(None, description="描述")
+    dataset_id: int = Field(..., description="数据集ID")
+    s3_object_sheet: str = Field(..., description="S3对象表")
+    object_cnt: Optional[int] = Field(None, description="对象数量")
+    data_size: Optional[int] = Field(None, description="数据大小")
+    user_upload_data_path: Optional[str] = Field(None, description="用户上传数据路径")
+    s3_target_path: str = Field(..., description="S3目标路径")
