@@ -17,14 +17,16 @@ from __future__ import annotations
 import mimetypes
 import os
 import pathlib
-import tempfile
 import time
 import uuid
+from pathlib import Path
 
 import httpx
 from loguru import logger
+from minio import Minio
 
 from ..exceptions import APIError
+from ..models.artifact import StsResp
 from ..models.common import APIWrapper
 from ..models.dataset_management import (
     CreateDatasetRequest,
@@ -40,9 +42,13 @@ from ..models.dataset_management import (
     ListDatasetResp,
     ListDatasetVersionReq,
     ListDatasetVersionResp,
+    CreateDatasetVersionByDataIngestReqV2,
+    UploadType,
 )
 from ..models.dataset_management import DatasetVersionStatus
-from ..utils.download import dataset_download, zip_dir
+from ..utils.di import SimpleS3Client, DataUploader
+from ..utils.download import dataset_download
+from ..utils.s3 import upload_dir_to_s3
 
 _BASE = "/dataset-mng/api/v2"
 
@@ -138,20 +144,30 @@ class DatasetManagementService:
     def dataset(self) -> _Dataset:
         return self._dataset
 
+    def _get_sts(self) -> StsResp:
+        return self.dataset_version.get_sts()
+
     @property
     def dataset_version(self) -> _DatasetVersion:
         return self._dataset_version
 
+    def upload_by_data_ingest(
+        self,
+        req: CreateDatasetVersionByDataIngestReqV2,
+    ) -> CreateDatasetVersionResponse:
+        return self.dataset_version.upload_by_data_ingest(req)
+
     def create_dataset_and_version(
-            self,
-            *,
-            dataset_name: str,
-            dataset_description: str = "",
-            is_local_upload: bool,
-            local_file_path: str | None = None,
-            server_file_path: str | None = None,
-            version_description: str = "",
-            timeout: int = 1_800,
+        self,
+        *,
+        dataset_name: str,
+        dataset_description: str = "",
+        is_local_upload: bool,
+        local_file_path: str | None = None,
+        server_file_path: str | None = None,
+        version_description: str = "",
+        user_upload_data_path: str | None = None,
+        timeout: int = 1_800,
     ) -> tuple[int, int, str]:
         """创建数据集及其版本，并等待版本状态变为 *Success*。
 
@@ -166,20 +182,56 @@ class DatasetManagementService:
             server_file_path: 服务器已有文件路径，当 is_local_upload=False 时必须提供。
             version_description: 版本描述，默认为空。
             timeout: 最大等待秒数（默认1800s）。超过后仍未成功则引发 ``TimeoutError``。
+            user_upload_data_path: 用户本体数据的存储地址
 
         Returns:
            tuple[int, int, str]: 一个三元组，包含：[数据集 ID,数据集版本 ID, 数据集版本标签（格式为 <dataset_name>/V<version_number>)]
+
+        Raises:
+            ValueError: 当参数不满足要求时
+            APIError: 当后端返回错误时
+            TimeoutError: 当等待超时时
         """
+        # 参数校验
+        self._validate_create_params(is_local_upload, local_file_path, server_file_path)
+
+        # 创建数据集
+        dataset_id = self._create_dataset(dataset_name, dataset_description)
+        logger.info(f"创建数据集成功，名称为 {dataset_name} ,开始准备创建版本、上传数据")
+
+        # 创建数据集版本
+        version_id = self._create_dataset_version(
+            dataset_id=dataset_id,
+            is_local_upload=is_local_upload,
+            local_file_path=local_file_path,
+            server_file_path=server_file_path,
+            version_description=version_description,
+            user_upload_data_path=user_upload_data_path,
+        )
+
+        # 获取版本标签
+        version_tag = self._get_version_tag(dataset_id, version_id)
+        logger.info(f"数据集版本创建成功，名称为 {version_tag}，开始轮询状态…")
+
+        # 轮询等待版本状态变为成功
+        self._wait_for_version_success(version_id, timeout)
+
+        return dataset_id, version_id, version_tag
+
+    def _validate_create_params(
+        self, is_local_upload: bool, local_file_path: str | None, server_file_path: str | None
+    ) -> None:
+        """验证创建数据集和版本所需的参数"""
         if is_local_upload:
             if not local_file_path:
                 raise ValueError("is_local_upload=True 时必须提供 local_file_path")
-            upload_type = 1
         else:
             if not server_file_path:
                 raise ValueError("is_local_upload=False 时必须提供 server_file_path")
-            upload_type = 3
 
-        dataset_id = self._dataset.create(
+    def _create_dataset(self, dataset_name: str, dataset_description: str) -> int:
+        """创建数据集"""
+        return self._dataset.create(
             CreateDatasetRequest(
                 name=dataset_name,
                 description=dataset_description,
@@ -190,39 +242,103 @@ class DatasetManagementService:
                 access_user_ids=None,
             )
         )
-        logger.info(
-            f"创建数据集成功，名称为 {dataset_name} ,开始准备创建版本、上传数据"
+
+    def _create_dataset_version(
+        self,
+        dataset_id: int,
+        is_local_upload: bool,
+        local_file_path: str | None,
+        server_file_path: str | None,
+        version_description: str,
+        user_upload_data_path: str | None,
+    ) -> int:
+        """根据上传类型创建数据集版本"""
+        if is_local_upload:
+            return self._create_local_dataset_version(
+                dataset_id, local_file_path, version_description, user_upload_data_path
+            )
+        else:
+            return self._create_server_dataset_version(dataset_id, server_file_path, version_description)
+
+    def _create_local_dataset_version(
+        self, dataset_id: int, local_file_path: str | None, version_description: str, user_upload_data_path: str | None
+    ) -> int:
+        """创建本地文件数据集版本"""
+        if pathlib.Path(local_file_path).is_dir():
+            return self._create_local_dir_dataset_version(dataset_id, local_file_path, user_upload_data_path)
+        elif pathlib.Path(local_file_path).is_file():
+            return self._create_local_file_dataset_version(dataset_id, local_file_path, version_description)
+        else:
+            raise ValueError(f"本地路径既不是文件也不是目录: {local_file_path}")
+
+    def _create_local_dir_dataset_version(
+        self, dataset_id: int, local_file_path: str, user_upload_data_path: str
+    ) -> int:
+        """处理本地目录上传"""
+        sts = self._get_sts()
+        s3_client = SimpleS3Client(
+            sts.endpoint, sts.access_key_id, sts.secret_access_key, session_token=sts.session_token
+        )
+        uid = uuid.uuid4().hex
+        s3_target = f"s3://{sts.bucket}/dataset_workspace/{dataset_id}/{uid}"
+        s3_csv_path = f"s3://{sts.bucket}/dataset_workspace/{dataset_id}/{uid}.csv"
+        s3_status_path = f"s3://{sts.bucket}/dataset_workspace/{dataset_id}/{uid}.json"
+
+        # 创建上传器并执行
+        uploader = DataUploader(
+            task_id=dataset_id,
+            local_path=str(local_file_path),
+            s3_target=s3_target,
+            csv_path=s3_csv_path,
+            status_path=s3_status_path,
+            num_workers=40,
         )
 
-        if is_local_upload:
-            # 上传文件，检查是文件夹还是zip
-            local_file_path = pathlib.Path(local_file_path)
-            if local_file_path.is_dir():
-                # 把文件夹打包为一个 zip
-                temp_zip_path = (
-                        pathlib.Path(tempfile.mkdtemp()) / f" {uuid.uuid4().hex}.zip"
-                )
-                zip_dir(local_file_path, temp_zip_path)
-                upload_data = self._upload.upload_file(temp_zip_path)
-                os.remove(temp_zip_path)
-            else:
-                upload_data = self._upload.upload_file(local_file_path)
+        upload_stats = uploader.run(s3_client)
+        req = CreateDatasetVersionByDataIngestReqV2(
+            description=f"sdk 上传",
+            dataset_id=dataset_id,
+            s3_object_sheet=s3_csv_path,
+            object_cnt=upload_stats.uploaded_count,
+            data_size=upload_stats.uploaded_size,
+            user_upload_data_path=user_upload_data_path,
+            s3_target_path=s3_target,
+        )
+        return self.upload_by_data_ingest(req).id
 
-            upload_path = upload_data.path
-        else:
-            upload_path = server_file_path
+    def _create_local_file_dataset_version(
+        self, dataset_id: int, local_file_path: str, version_description: str
+    ) -> int:
+        """处理本地文件上传"""
+        upload_data = self._upload.upload_file(local_file_path)
+        upload_path = upload_data.path
         logger.info(f"文件上传成功：{local_file_path}")
-
-        version_id = self._dataset_version.upload(
+        return self._dataset_version.upload(
             UploadDatasetVersionRequest(
                 upload_path=upload_path,
-                upload_type=upload_type,
+                upload_type=UploadType.LOCAL,  # 本地上传类型
                 dataset_id=dataset_id,
                 description=version_description,
                 parent_version_id=0,
             )
         )
 
+    def _create_server_dataset_version(
+        self, dataset_id: int, server_file_path: str | None, version_description: str
+    ) -> int:
+        """创建服务器文件数据集版本"""
+        return self._dataset_version.upload(
+            UploadDatasetVersionRequest(
+                upload_path=server_file_path,
+                upload_type=UploadType.SERVER_PATH,  # 服务器文件上传类型
+                dataset_id=dataset_id,
+                description=version_description,
+                parent_version_id=0,
+            )
+        )
+
+    def _get_version_tag(self, dataset_id: int, version_id: int) -> str:
+        """获取版本标签"""
         detail = self._dataset.get(dataset_id)
         ver_num = next(
             (v.version for v in detail.versions if v.id == version_id),
@@ -231,9 +347,10 @@ class DatasetManagementService:
         if ver_num is None:
             ver_num = 1
 
-        version_tag = f"{detail.name}/V{ver_num}"
-        logger.info(f"数据集版本创建成功，名称为 {version_tag}，开始轮询状态…")
+        return f"{detail.name}/V{ver_num}"
 
+    def _wait_for_version_success(self, version_id: int, timeout: int) -> None:
+        """轮询等待版本状态变为成功"""
         start_ts = time.time()
         poll_interval = 10
 
@@ -255,8 +372,6 @@ class DatasetManagementService:
             logger.debug(f"已等待 {elapsed:.0f}s，继续轮询…")
             time.sleep(poll_interval)
 
-        return dataset_id, version_id, version_tag
-
     def run_download(self, dataset_version_name: str, local_dir: str, worker: int = 4) -> None:
         """根据数据集版本名称下载对应的数据集文件。
 
@@ -284,7 +399,7 @@ class DatasetManagementService:
         name: str | None = None,
         tags: str | None = None,
         create_by: int | None = None,
-        scope: str = "all"
+        scope: str = "all",
     ) -> ListDatasetResp:
         """列表查询数据集
 
@@ -300,12 +415,7 @@ class DatasetManagementService:
             ListDatasetResp: 数据集列表响应，包含分页信息和数据集列表
         """
         payload = ListDatasetReq(
-            page_size=page_size,
-            page_num=page_num,
-            name=name,
-            tags=tags,
-            create_by=create_by,
-            scope=scope
+            page_size=page_size, page_num=page_num, name=name, tags=tags, create_by=create_by, scope=scope
         )
         return self._dataset.list_datasets(payload)
 
@@ -315,7 +425,7 @@ class DatasetManagementService:
         page_size: int = 10000000,
         page_num: int = 1,
         dataset_id: int | None = None,
-        dataset_version_ids: str | None = None
+        dataset_version_ids: str | None = None,
     ) -> ListDatasetVersionResp:
         """列表查询数据集版本
 
@@ -329,13 +439,30 @@ class DatasetManagementService:
             ListDatasetVersionResp: 数据集版本列表响应，包含分页信息和数据集版本列表
         """
         payload = ListDatasetVersionReq(
-            page_size=page_size,
-            page_num=page_num,
-            dataset_id=dataset_id,
-            dataset_version_ids=dataset_version_ids
+            page_size=page_size, page_num=page_num, dataset_id=dataset_id, dataset_version_ids=dataset_version_ids
         )
         return self._dataset_version.list_dataset_versions(payload)
 
+    def upload_data(self, local_path: str) -> str:
+
+        sts = self._get_sts()
+
+        s3_client = Minio(
+            endpoint=sts.endpoint,
+            access_key=sts.access_key_id,
+            secret_key=sts.secret_access_key,
+            session_token=sts.session_token,
+            secure=False,
+        )
+        s3_prefix = f"user_data/{uuid.uuid4().hex}"
+        if Path(local_path).is_file():
+            s3_key = f"{s3_prefix}/{Path(local_path).name}"
+            s3_client.fput_object(bucket_name=sts.bucket, object_name=s3_prefix, file_path=local_path)
+            return f"s3://{sts.bucket}/{s3_key}"
+        else:
+            upload_dir_to_s3(s3_client, local_path, sts.bucket, s3_prefix)
+            return f"s3://{sts.bucket}/{s3_prefix}"
+
 
 class _Dataset:
     def __init__(self, http: httpx.Client):
@@ -348,7 +475,7 @@ class _Dataset:
         )
         wrapper = APIWrapper[CreateDatasetResponse].model_validate(resp.json())
         if wrapper.code != 0:
-            raise APIError(f"backend code {wrapper.code}: {wrapper.msg}")
+            raise APIError(f"backend code {wrapper.code}: {wrapper.msg} in  create dataset")
         return wrapper.data.id
 
     def get(self, dataset_id: int) -> DatasetDetail:
@@ -362,6 +489,8 @@ class _Dataset:
         """列表查询数据集"""
         params = payload.model_dump(by_alias=True, exclude_none=True)
         resp = self._http.get(f"{_BASE}/datasets", params=params)
+        if resp.status_code != 200:
+            raise APIError(f"backend code {resp.status_code}: {resp.text}", status=resp.status_code)
         wrapper = APIWrapper[ListDatasetResp].model_validate(resp.json())
         if wrapper.code != 0:
             raise APIError(f"backend code {wrapper.code}: {wrapper.msg}")
@@ -377,6 +506,8 @@ class _DatasetVersion:
             f"{_BASE}/dataset-versions",
             json=payload.model_dump(by_alias=True, exclude_none=True),
         )
+        if resp.status_code != 200:
+            raise APIError(f"backend code {resp.status_code}: {resp.text}", status=resp.status_code)
         wrapper = APIWrapper[CreateDatasetVersionResponse].model_validate(resp.json())
         if wrapper.code != 0:
             raise APIError(f"backend code {wrapper.code}: {wrapper.msg}")
@@ -387,6 +518,8 @@ class _DatasetVersion:
             f"{_BASE}/dataset-versions-upload",
             json=payload.model_dump(by_alias=True, exclude_none=True),
         )
+        if resp.status_code != 200:
+            raise APIError(f"backend code {resp.status_code}: {resp.text}", status=resp.status_code)
         wrapper = APIWrapper[UploadDatasetVersionResponse].model_validate(resp.json())
         if wrapper.code != 0:
             raise APIError(f"backend code {wrapper.code}: {wrapper.msg}")
@@ -394,15 +527,18 @@ class _DatasetVersion:
 
     def get(self, version_id: int) -> DatasetVersionDetail:
         resp = self._http.get(f"{_BASE}/dataset-versions/{version_id}")
+        if resp.status_code != 200:
+            raise APIError(f"backend code {resp.status_code}: {resp.text}", status=resp.status_code)
         wrapper = APIWrapper[DatasetVersionDetail].model_validate(resp.json())
+
         if wrapper.code != 0:
             raise APIError(f"backend code {wrapper.code}: {wrapper.msg}")
         return wrapper.data
 
     def get_by_name(self, version_name: str) -> DatasetVersionDetail:
-        resp = self._http.get(
-            f"{_BASE}/dataset-versions-detail", params={"name": version_name}
-        )
+        resp = self._http.get(f"{_BASE}/dataset-versions-detail", params={"name": version_name})
+        if resp.status_code != 200:
+            raise APIError(f"backend code {resp.status_code}: {resp.text}", status=resp.status_code)
         wrapper = APIWrapper[DatasetVersionDetail].model_validate(resp.json())
         if wrapper.code != 0:
             raise APIError(f"backend code {wrapper.code}: {wrapper.msg}")
@@ -412,11 +548,49 @@ class _DatasetVersion:
         """列表查询数据集版本"""
         params = payload.model_dump(by_alias=True, exclude_none=True)
         resp = self._http.get(f"{_BASE}/dataset-versions", params=params)
+        if resp.status_code != 200:
+            raise APIError(f"backend code {resp.status_code}: {resp.text}", status=resp.status_code)
         wrapper = APIWrapper[ListDatasetVersionResp].model_validate(resp.json())
         if wrapper.code != 0:
             raise APIError(f"backend code {wrapper.code}: {wrapper.msg}")
         return wrapper.data
 
+    def get_sts(self) -> StsResp:
+        """获取STS临时凭证
+
+        获取用于访问S3存储的临时凭证。
+
+        Returns:
+            StsResp: STS临时凭证信息
+
+        Raises:
+            APIError: 当API调用失败时抛出
+        """
+        resp = self._http.get(f"{_BASE}/dataset-versions/get-sts")
+        if resp.status_code != 200:
+            raise APIError(f"backend code {resp.status_code}: {resp.text}", status=resp.status_code)
+        wrapper = APIWrapper[StsResp].model_validate(resp.json())
+        if wrapper.code != 0:
+            raise APIError(f"backend code {wrapper.code}: {wrapper.msg}")
+        return wrapper.data
+
+    def upload_by_data_ingest(self, req: CreateDatasetVersionByDataIngestReqV2) -> CreateDatasetVersionResponse:
+        """上传数据集版本（数据集导入）
+        Args:
+            req
+
+        """
+        resp = self._http.post(
+            f"{_BASE}/dataset-versions/data-ingest",
+            json=req.model_dump(),
+        )
+        if resp.status_code != 200:
+            raise APIError(f"backend code {resp.status_code}: {resp.text}", status=resp.status_code)
+        wrapper = APIWrapper[CreateDatasetVersionResponse].model_validate(resp.json())
+        if wrapper.code != 0:
+            raise APIError(f"backend code {wrapper.code}: {wrapper.msg}")
+        return wrapper.data
+
 
 class _Upload:
     def __init__(self, http: httpx.Client):
