@@ -290,9 +290,9 @@ class UserSystemService:
     def delete_user(self, user_id: int) -> None:
         """删除用户
 
-         Args:
-             user_id: 目标用户 ID
-         """
+        Args:
+            user_id: 目标用户 ID
+        """
         self._user.delete(user_id)
 
     def set_user_roles(self, user_id: int, payload: SetUserRolesRequest) -> None:
@@ -304,7 +304,12 @@ class UserSystemService:
         """
         self._user.set_roles(user_id, payload)
 
-    def get_user_menus(self, user_id: int, parent_id: int | None = None, auth: str | None = None, ) -> List[TreeMenu]:
+    def get_user_menus(
+        self,
+        user_id: int,
+        parent_id: int | None = None,
+        auth: str | None = None,
+    ) -> List[TreeMenu]:
         """查询用户可见菜单
 
         Args:
@@ -317,7 +322,7 @@ class UserSystemService:
         """
         return self._user.get_menus(user_id, parent_id=parent_id, auth=auth)
 
-    def search_users(self, payload: SearchUsersRequest) -> SearchUsersResponse:
+    def search_users(self, payload: SearchUsersRequest) -> List[User]:
         """条件搜索用户
 
         Args:
@@ -326,13 +331,15 @@ class UserSystemService:
         Returns:
             SearchUsersResponse: 搜索结果
         """
-        return self._user.search(payload)
+        resp = self._user.search(payload)
+        return resp.data
 
-    def search_one(self, payload: SearchUsersRequest) -> int:
+    def search_one(self, nickname: str) -> int:
         """搜索单个用户并返回其 ID
 
         Args:
-            payload: 搜索条件
+            nickname: 用户昵称
+
 
         Returns:
             int: 命中的用户 ID
@@ -340,7 +347,10 @@ class UserSystemService:
         Raises:
             APIError: 未找到用户时抛出
         """
-        return self._user.search_one(payload)
+        req = SearchUsersRequest(
+            nickname=nickname,
+        )
+        return self._user.search_one(req)
 
     @property
     def auth(self) -> _Auth:
@@ -568,6 +578,13 @@ class _User:
 
     def search_one(self, req: SearchUsersRequest) -> int:
         resp = self.search(req)
+
+        if resp.data is None:
+            raise APIError(f"no user found")
+
+        if len(resp.data) > 1:
+            raise APIError("more than one user found")
+
         for user in resp.data:
             if user.nickname == req.nickname:
                 return user.id
