@@ -13,15 +13,13 @@ class TestDatasetManagement(unittest.TestCase):
     def test_create_dataset_and_version(self):
         client = Client(base_url=BASE_URL, token=TOKEN)
         dataset_name = f"sdk_dataset_{uuid.uuid4().hex[:6]}"
-        dataset_id, dataset_version_id, version_tag = (
-            client.dataset_management.create_dataset_and_version(
-                dataset_name=dataset_name,
-                dataset_description="xxxxx",
-                is_local_upload=True,
-                local_file_path=r"C:\Users\admin\Desktop\hbase\images.zip",
-                server_file_path="",
-                version_description="yyyyy",
-            )
+        dataset_id, dataset_version_id, version_tag = client.dataset_management.create_dataset_and_version(
+            dataset_name=dataset_name,
+            dataset_description="xxxxx",
+            is_local_upload=True,
+            local_file_path=r"C:\Users\admin\Desktop\hbase\images.zip",
+            server_file_path="",
+            version_description="yyyyy",
         )
         print("dataset_id:", dataset_id)
         print("dataset_version_id:", dataset_version_id)
@@ -31,7 +29,7 @@ class TestDatasetManagement(unittest.TestCase):
         client = Client(base_url=BASE_URL, token=TOKEN)
         client.dataset_management.run_download(
             dataset_version_name="re/V12",
-            local_dir=r"C:\Users\admin\Downloads\ljn",
+            local_dir=r"./data/output",
             worker=4,
         )
         print("Done!")
@@ -39,15 +37,13 @@ class TestDatasetManagement(unittest.TestCase):
     def test_upload_dir(self):
         client = Client(base_url=BASE_URL, token=TOKEN)
         dataset_name = f"sdk_dataset_{uuid.uuid4().hex[:6]}"
-        dataset_id, dataset_version_id, version_tag = (
-            client.dataset_management.create_dataset_and_version(
-                dataset_name=dataset_name,
-                dataset_description="xxxxx",
-                is_local_upload=True,
-                local_file_path="./data",
-                server_file_path="",
-                version_description="yyyyy",
-            )
+        dataset_id, dataset_version_id, version_tag = client.dataset_management.create_dataset_and_version(
+            dataset_name=dataset_name,
+            dataset_description="xxxxx",
+            is_local_upload=True,
+            local_file_path="./data",
+            server_file_path="",
+            version_description="yyyyy",
         )
         print("dataset_id:", dataset_id)
         print("dataset_version_id:", dataset_version_id)
